#coding:utf-8
from os.path import abspath,dirname,join,normpath
import sys

#初始化python的查找路径
PREFIX = normpath(dirname(dirname(abspath(__file__))))
if PREFIX not in sys.path:
    sys.path=[PREFIX] + sys.path

#数据库配置
DATABASE_CONFIG = {
    "wtree": {
        "master": "localhost:3306:wtree:root:111111",
        "tables": ["*","user"],
    },
}

#是否启用在线调试
DEBUG = True

#是否使用优化过的css，js
MERGE_CSS_JS = False

#是否启用Mako的自动检测模板更新
MAKO_FILESYSTEM_CHECK = True

#是否python由提供静态文件的服务
SERVER_STATIC_FILE = True

#静态文件服务器的域名
FILE_HOST = ""

#Javascript文件服务器的域名
JS_FILE_HOST = ""

#Memcache的地址
MEMCACHED_ADDR = None
#MEMCACHED_ADDR = ["127.0.0.1:11211"]

#是否禁用进程内缓存
DISABLE_LOCAL_CACHED = False

try:
    from local_config import *
except ImportError:
    print "WARNING : local_config not exist"
